from netbox.api.fields import ContentTypeField
from netbox.api.serializers import NetBoxModelSerializer

from ipfabric_netbox.models import IPFabricSnapshot
from ipfabric_netbox.models import IPFabricSource
from ipfabric_netbox.models import IPFabricTransformMap

__all__ = (
    "NestedIPFabricSourceSerializer",
    "NestedIPFabricSnapshotSerializer",
    "NestedIPFabricTransformMapSerializer",
)


class NestedIPFabricSourceSerializer(NetBoxModelSerializer):
    class Meta:
        model = IPFabricSource
        fields = ["id", "url", "display", "name"]


class NestedIPFabricSnapshotSerializer(NetBoxModelSerializer):
    source = NestedIPFabricSourceSerializer(read_only=True)

    class Meta:
        model = IPFabricSnapshot
        fields = ["id", "name", "source", "snapshot_id", "date", "display", "sites"]


class NestedIPFabricTransformMapSerializer(NetBoxModelSerializer):
    target_model = ContentTypeField(read_only=True)

    class Meta:
        model = IPFabricTransformMap
        fields = [
            "id",
            "source_model",
            "target_model",
            "status",
        ]



from django.db import connection
from extras.plugins import PluginConfig


class NetboxIPFabricConfig(PluginConfig):
    name = "ipfabric_netbox"
    verbose_name = "NetBox IP Fabric SoT Plugin"
    description = "Sync IP Fabric into NetBox"
    version = "1.0.7"
    base_url = "ipfabric"

    def ready(self):
        super().ready()
        from ipfabric_netbox.signals import ipfabric_netbox_init

        all_tables = connection.introspection.table_names()
        if "extras_customfield" in all_tables:
            ipfabric_netbox_init()


config = NetboxIPFabricConfig
